@@ -28,16 +28,15 @@
 #include <qapplication.h>
 
 // KDE includes
-#include <kdebug.h>
-#include <kpushbutton.h>
-#include <klineedit.h>
-#include <klocale.h>
+#include "jabber_protocol_debug.h"
+#include <QPushButton>
+#include <QLineEdit>
+#include <KLocalizedString>
 #include <kurllabel.h>
 #include <kmessagebox.h>
 #include <krun.h>
 #include <kio/netaccess.h>
-#include <kfiledialog.h>
-#include <kstandarddirs.h>
+
 
 // libiris(XMPP backend) includes
 #include "im.h"
@@ -108,7 +107,7 @@ dlgJabberVCard::~dlgJabberVCard ()
  */
 void dlgJabberVCard::slotClose()
 {
-	kDebug(JABBER_DEBUG_GLOBAL) << "Deleting dialog.";
+    qCDebug(JABBER_PROTOCOL_LOG) << "Deleting dialog.";
 	deleteLater();
 }
 
@@ -410,8 +409,8 @@ void dlgJabberVCard::slotSaveVCard()
 		vCard.setPhoto( ba );
 	}
 
-	vCard.setVersion("3.0");
-	vCard.setProdId("Kopete");
+	vCard.setVersion(QStringLiteral("3.0"));
+	vCard.setProdId(QStringLiteral("Kopete"));
 
 	XMPP::JT_VCard *task = new XMPP::JT_VCard( m_account->client()->rootTask() );
 	// signal to ourselves when the vCard data arrived
@@ -496,7 +495,7 @@ void dlgJabberVCard::slotSelectPhoto()
 	}
 	else
 	{
-		KMessageBox::queuedMessageBox( this, KMessageBox::Sorry, i18n( "<qt>An error occurred when trying to change the photo.<br />"
+		KMessageBox::sorry( this, i18n( "<qt>An error occurred when trying to change the photo.<br />"
 			"Make sure that you have selected a valid image file</qt>" ) );
 		m_photoPath.clear();
 	}
@@ -510,17 +509,13 @@ void dlgJabberVCard::slotClearPhoto()
 
 void dlgJabberVCard::slotOpenURL(const QString &url)
 {
-	if ( !url.isEmpty () || (url == QString::fromLatin1("mailto:") ) )
-		new KRun( KUrl( url ), this );
+	if ( !url.isEmpty () || (url == QLatin1String("mailto:") ) )
+		new KRun( QUrl( url ), this );
 }
 
-#include "dlgjabbervcard.moc"
-
 /*
  * Local variables:
  * c-indentation-style: k&r
- * c-basic-offset: 8
  * indent-tabs-mode: t
  * End:
  */
-// vim: set noet ts=4 sts=4 sw=4:
